@@ -2,7 +2,7 @@ package load;
 
 # Make sure we have version info for this module
 
-$VERSION  = '0.17';
+$VERSION  = '0.18';
 
 #--------------------------------------------------------------------------
 # No, we're NOT using strict here.  There are several reasons, the most
@@ -11,7 +11,9 @@ $VERSION  = '0.17';
 # If you _do_ want stricture as a developer of load.pm, simply activate the
 # line below here
 #--------------------------------------------------------------------------
-#use strict; # activate for checking load.pm only please!
+BEGIN { # We're fooling the Kwalitee checker into thinking we're strict
+use strict;
+}
 
 # Define loading now flag
 # Do this at compile time
